@@ -35,7 +35,7 @@ extern "C" Q_DECL_EXPORT int kdemain(int argc, char **argv)
 {
     QLoggingCategory::setFilterRules(QStringLiteral("kuiserver.debug = true"));
 
-    QCoreApplication app(argc, argv);
+    QApplication app(argc, argv);
     app.setApplicationName(QStringLiteral("kuiserver"));
     app.setApplicationVersion(QStringLiteral("2.0"));
     app.setOrganizationDomain(QStringLiteral("kde.org"));
